@@ -189,7 +189,7 @@ refit_multiple_optimizers <- function(fit,
     )
   }
   best_optimizer <- which.max(all_fits_summary$log_liks[is_ok])
-  all_fits[[best_optimizer]]
+  all_fits[[which(is_ok)[best_optimizer]]]
 }
 
 #' Control Parameters for Fitting an MMRM
@@ -201,8 +201,8 @@ refit_multiple_optimizers <- function(fit,
 #' @param n_cores (`count`)\cr number of cores to be used.
 #' @param method (`string`)\cr adjustment method for degrees of freedom.
 #' @param vcov (`string`)\cr coefficients covariance matrix adjustment method.
-#' @param start (`numeric` or `NULL`)\cr optional start values for variance
-#'   parameters.
+#' @param start (`NULL`, `numeric` or `function`)\cr optional start values for variance
+#'   parameters. See details for more information.
 #' @param accept_singular (`flag`)\cr whether singular design matrices are reduced
 #'   to full rank automatically and additional coefficient estimates will be missing.
 #' @param optimizers (`list`)\cr optimizer specification, created with [h_get_optimizers()].
@@ -240,6 +240,12 @@ refit_multiple_optimizers <- function(fit,
 #'   compared to SAS; Use "Kenward-Roger-Linear" for `vcov` instead for better matching
 #'   of the SAS results.
 #'
+#' - The argument `start` is used to facilitate the choice of initial values for fitting the model.
+#'   If `function` is provided, make sure its parameter is a valid element of `mmrm_tmb_data`
+#'   or `mmrm_tmb_formula_parts` and it returns a numeric vector.
+#'   By default or if `NULL` is provided, `std_start` will be used.
+#'   Other implemented methods include `emp_start`.
+#'
 #' @return List of class `mmrm_control` with the control parameters.
 #' @export
 #'
@@ -251,14 +257,21 @@ refit_multiple_optimizers <- function(fit,
 mmrm_control <- function(n_cores = 1L,
                          method = c("Satterthwaite", "Kenward-Roger", "Residual", "Between-Within"),
                          vcov = NULL,
-                         start = NULL,
+                         start = std_start,
                          accept_singular = TRUE,
                          drop_visit_levels = TRUE,
                          ...,
                          optimizers = h_get_optimizers(...)) {
   assert_count(n_cores, positive = TRUE)
   assert_character(method)
-  assert_numeric(start, null.ok = TRUE)
+  if (is.null(start)) {
+    start <- std_start
+  }
+  assert(
+    check_function(start, args = "..."),
+    check_numeric(start, null.ok = FALSE),
+    combine = "or"
+  )
   assert_flag(accept_singular)
   assert_flag(drop_visit_levels)
   assert_list(optimizers, names = "unique", types = c("function", "partial"))
